#include "osl/hash/boardKey.tcc"

template class osl::hash::GeneralBoardKey<unsigned int,4>;
template class osl::hash::GeneralBoardKey<unsigned long long,2>;
template struct osl::hash::GeneralHashKey<osl::hash::BoardKey32>;
template struct osl::hash::GeneralHashKey<osl::hash::BoardKey64>;


// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:
